@@ -54,8 +54,8 @@ TYPES = {
 
 	'Class/knh_class_t' : 'knh_Class_cid((Class*)%s)',
 	'Class/knh_type_t':   'knh_Class_cid((Class*)%s)',
-	'knh_class_t/Class':  'knh_tClass_class(ctx, %s)', 
-	'knh_type_t/Class':   'knh_tClass_class(ctx, %s)',
+	'knh_class_t/Class':  'knh_ClassTable_class(ctx, %s)', 
+	'knh_type_t/Class':   'knh_ClassTable_class(ctx, %s)',
 
 	'void/void':	   '%s',
 }
@@ -82,7 +82,7 @@ def mapfunc(t1, n1, t2, n2, data):
 def write_flag_h(f, c, fb, n):
 	if c == None: return
 	if fb.index == None:
-		write_define(f, fb.KNH_FLAG, 'KNH_FLAG%d' % n, 40)
+		write_define(f, fb.KNH_FLAG, 'KNH_FLAG_T%d' % n, 40)
 	else:
 		write_define(f, fb.KNH_FLAG, 'KNH_FLAG_OF_LOCAL%s' % fb.index, 40)
 
@@ -142,7 +142,7 @@ def write_class_h(f, c, n):
 		write_define(f, STRUCT_cname(c.cname), c.struct_name.replace('knh_', 'STRUCT_').replace('_t', ''), 32)
 	else:
 		write_define(f, STRUCT_cname(c.cname), 'BSIZE_TOSID(sizeof(%s)/sizeof(Object*))' % c.struct_name, 32)
-	write_define(f, CLASS_cname(c.cname), '((knh_class_t)KNH_TSTRUCT_SIZE+%d)' % n, 32)
+	write_define(f, CLASS_cname(c.cname), '((knh_class_t)KNH_TCLASS_SIZE-(%d+1))' % n, 32)
 	write_class0_h(f, c, n)
 
 def write_fieldn_h(f, data):
@@ -210,7 +210,7 @@ def gen_class_h(bdir, data):
 	for cname in data.ACLASS_LIST:
 		cname = cname.replace(":", "__")
 		if cname == 'Int' or cname == 'Float': continue
-		write_define(f, 'ACLASS_%s' % cname, '((knh_class_t)(KNH_TSTRUCT_SIZE+%d))' % cn, 32)
+		write_define(f, 'ACLASS_%s' % cname, '((knh_class_t)(KNH_TCLASS_SIZE-(%d+1)))' % cn, 32)
 		write_define(f, 'ATYPE_%s' % cname, 'ACLASS_%s' % cname, 32)
 		write_define(f, 'NNATYPE_%s' % cname, 'NNTYPE_cid(ACLASS_%s)' % cname, 32)
 		cn += 1
@@ -218,14 +218,14 @@ def gen_class_h(bdir, data):
 	write_chapter(f, '[Iterator<X>]')
 	for cname in data.ICLASS_LIST:
 		cname = cname.replace(":", "__")
-		write_define(f, 'ICLASS_%s' % cname, '((knh_class_t)(KNH_TSTRUCT_SIZE+%d))' % cn, 32)
+		write_define(f, 'ICLASS_%s' % cname, '((knh_class_t)(KNH_TCLASS_SIZE-(%d+1)))' % cn, 32)
 		write_define(f, 'ITYPE_%s' % cname, 'NNTYPE_cid(ICLASS_%s)' % cname, 32)
 		write_define(f, 'NNITYPE_%s' % cname, 'NNTYPE_cid(ICLASS_%s)' % cname, 32)
 		cn += 1
 	
 	write_chapter(f, '[Generics]')
 	for c in data.GENERICS_LIST:
-		write_define(f, 'CLASS_%s' % c.cname, '((knh_class_t)(KNH_TSTRUCT_SIZE+%d))' % cn, 32)
+		write_define(f, 'CLASS_%s' % c.cname, '((knh_class_t)(KNH_TCLASS_SIZE-(%d+1)))' % cn, 32)
 		write_define(f, 'TYPE_%s' % c.cname, 'CLASS_%s' % c.cname, 32)
 		write_define(f, 'NNTYPE_%s' % c.cname, 'NNTYPE_cid(CLASS_%s)' % cname, 32)
 		cn += 1
@@ -233,7 +233,7 @@ def gen_class_h(bdir, data):
 	write_chapter(f, '[Object:X]')
 	for cname in data.XCLASS_LIST:
 		cname = cname.replace(":", "__")
-		write_define(f, 'CLASS_%s' % cname, '((knh_class_t)(KNH_TSTRUCT_SIZE+%d))' % cn, 32)
+		write_define(f, 'CLASS_%s' % cname, '((knh_class_t)(KNH_TCLASS_SIZE-(%d+1)))' % cn, 32)
 		write_define(f, 'TYPE_%s' % cname, 'CLASS_%s' % cname, 32)
 		write_define(f, 'NNTYPE_%s' % cname, 'NNTYPE_cid(CLASS_%s)' % cname, 32)
 		cn += 1
@@ -243,7 +243,7 @@ def gen_class_h(bdir, data):
 	for t in data.STEXT_LIST:
 		nm = data.STEXT_MAP[t]
 		write_define(f, 'TSN_%s' % nm, '%d' % cn, 32)
-		write_define(f, 'TS_%s' % nm, '((ctx)->tString[TSN_%s])' % nm)
+		write_define(f, 'TS_%s' % nm, '((ctx)->share->tString[TSN_%s])' % nm)
 		cn += 1
 	write_define(f, 'KNH_TSTRING_SIZE', '%d' % cn, 32)
 	
@@ -591,7 +591,8 @@ def write_structdata_c(f, c, data):
 \t\t(knh_fstruct_traverse)$CF_traverse,
 \t\t(knh_fstruct_compareTo)$CF_compareTo,
 \t\t(knh_fstruct_hashCode)$CF_hashCode,
-\t\t(knh_fstruct_newClass)$CF_newClass
+\t\t(knh_fstruct_newClass)$CF_newClass,
+\t\t$CF_getkey
 \t},'''.replace('$CF', c.funcbase).replace('$C', c.cname).replace('_Object_', '_ObjectField_')
 	f.write(fmt % (c.cname, size))
 
