@@ -190,7 +190,7 @@ CTYPE = {
 	'sfi' : 'knh_sfi_t', 
 	'sfx' : 'knh_sfx_t',
 	'boolean': 'knh_boolean_t',
-	'integer': 'knh_integer_t',
+	'integer': 'knh_int_t',
 	'float': 'knh_float_t',
 	'cid': 'knh_class_t',
 	'type': 'knh_type_t',
@@ -426,7 +426,7 @@ def write_dump(f):
 #define knh_write__boolean(ctx, w, a)  knh_write__s(ctx, w, (a) ? "true" : "false")
 #define knh_write__cid(ctx, w, a) knh_write_cid(ctx, w, a)
 #define knh_write__float(ctx, w, a) knh_write__f(ctx, w, a)
-#define knh_write__integer(ctx, w, a) knh_write_integerfmt(ctx, w, KNH_INTEGER_FMT, a)
+#define knh_write__integer(ctx, w, a) knh_write_integerfmt(ctx, w, KNH_INT_FMT, a)
 #define knh_write__OBJ(ctx, w, a)  knh_format(ctx, w, METHODN__k, a, KNH_NULL)
 #define knh_write__sfi(ctx, w, a)  knh_printf(ctx, w, "sfp[%d]", (int)a);
 #define knh_write__sfx(ctx, w, a)  knh_printf(ctx, w, "sfp[%d]+%d", (int)a.i, (int)a.n)
