@@ -250,7 +250,7 @@ typedef struct knh_KLRCode {
 	knh_code_t* code;
 	size_t size;
 	knh_fileid_t fileid;
-	knh_nsid_t nsid;
+//	knh_nsid_t nsid;
 	knh_dwarf_t* dwarf;
 	size_t dsize;
 } knh_KLRCode_struct;
