@@ -253,11 +253,11 @@ KNHAPI(char*) knh_format_ospath(Ctx *ctx, char *buf, size_t bufsiz, knh_bytes_t
 KNHAPI(void) konoha_SETv(Ctx *ctx, Object **v, Object *o);
 KNHAPI(void) konoha_FINALv(Ctx *ctx, Object **v);
 KNHAPI(char*) KNH_SAFEFILE(char *file);
-KNHAPI_(Object*) knh_boxing(Ctx *ctx, knh_sfp_t *sfp, knh_class_t cid);
-KNHAPI_(void) knh_sfp_boxing(Ctx *ctx, knh_sfp_t *sfp);
-KNHAPI_(void) knh_sfp_unboxing(Ctx *ctx, knh_sfp_t *sfp);
-KNHAPI(void) knh_sfp_sformat(Ctx *ctx, knh_sfp_t *lsfp, Method *mtd, OutputStream *w, Any *m);
-KNHAPI(void) knh_sfp_format(Ctx *ctx, knh_sfp_t *sfp, knh_methodn_t mn, OutputStream *w, Any *m);
+KNHAPI(Object*) new_Object_boxing(Ctx *ctx, knh_class_t cid, knh_sfp_t *sfp);
+KNHAPI(void) knh_sfp_boxing(Ctx *ctx, knh_sfp_t *sfp);
+KNHAPI(void) knh_sfp_unboxing(Ctx *ctx, knh_sfp_t *sfp);
+KNHAPI(void) knh_esp1_sformat(Ctx *ctx, Method *mtd, OutputStream *w, Any *m);
+KNHAPI(void) knh_esp1_format(Ctx *ctx, knh_methodn_t mn, OutputStream *w, Any *m);
 KNHAPI(void) knh_throw_TODO(Ctx *ctx, char *file, int line, char *func);
 KNHAPI(void) knh_throwException(Ctx *ctx, Exception *e, char *file, int line);
 KNHAPI(void) knh_throw__s(Ctx *ctx, char *msg, char *file, int line);
