@@ -48,7 +48,6 @@ Mapper *knh_tMapper_newIteratorArray(Ctx *ctx, knh_class_t icid, knh_class_t aci
 Mapper *knh_tMapper_newArrayIterator(Ctx *ctx, knh_class_t acid, knh_class_t icid);
 void knh_array_dfree(Ctx *ctx, void *ptr, size_t capacity, size_t usize);
 void knh_Iterator__k(Ctx *ctx, Iterator *o, OutputStream *w, String *m);
-void knh_Iterator__dump(Ctx *ctx, Iterator *o, OutputStream *w, String *m);
 /* ../src/api/dbapi.c */
 int knh_ResultSet_indexof_(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/api/hashapi.c */
@@ -594,6 +593,7 @@ knh_bool_t knh_Mapper_isNoSuchMapping(Mapper *mpr);
 Mapper *knh_tMapper_find_(Ctx *ctx, knh_class_t scid, knh_class_t tcid, int isgen);
 /* ../src/main/konoha_api.c */
 void konoha_init(void);
+int knh_readline_askYesNo(char *prompt, int def);
 METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_isStatement(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_readLine(Ctx *ctx, knh_sfp_t *sfp);
@@ -641,9 +641,9 @@ void knh_System_gc(Ctx *ctx);
 void knh_Object_RCsweep(Ctx *ctx, Object *o);
 knh_ftraverse konoha_getDefaultSweepFunc();
 /* ../src/main/stack.c */
-int knh_sfp_argc(Ctx *ctx, knh_sfp_t *varg);
+int knh_sfp_argc(Ctx *ctx, knh_sfp_t *v);
+METHOD knh__System_stackdump(Ctx *ctx, knh_sfp_t *sfp);
 char * knh_format_mtdparam(Ctx *ctx, char *buf, size_t bufsiz, Method *mtd, int n); void knh_sfp_typecheck(Ctx *ctx, knh_sfp_t *sfp, Method *mtd, knh_code_t *pc);
-void knh_sfp_dump(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/main/system.c */
 int konoha_existsConst(Ctx *ctx, knh_bytes_t name);
 Object *konoha_getConst(Ctx *ctx, knh_bytes_t name);
