@@ -613,7 +613,7 @@ static knh_ClassData_t ClassData[] = {
 	{"konoha.Array", CLASS_Array, CFLAG_Array, STRUCT_Array, CLASS_Object, 0, 31, 0, knh_Array_fdefault},
 	{"Int[]", CLASS_IArray, CFLAG_IArray, STRUCT_IArray, CLASS_Object, 0, 18, 0, knh_IArray_fdefault},
 	{"Float[]", CLASS_FArray, CFLAG_FArray, STRUCT_FArray, CLASS_Object, 0, 18, 0, knh_FArray_fdefault},
-	{"konoha.Iterator", CLASS_Iterator, CFLAG_Iterator, STRUCT_Iterator, CLASS_Object, 0, 2, 0, knh_Iterator_fdefault},
+	{"konoha.Iterator", CLASS_Iterator, CFLAG_Iterator, STRUCT_Iterator, CLASS_Object, 0, 1, 0, knh_Iterator_fdefault},
 	{"konoha.DictMap", CLASS_DictMap, CFLAG_DictMap, STRUCT_DictMap, CLASS_Object, 0, 12, 0, knh_DictMap_fdefault},
 	{"konoha.DictSet", CLASS_DictSet, CFLAG_DictSet, STRUCT_DictSet, CLASS_Object, 0, 13, 0, knh_DictSet_fdefault},
 	{"konoha.HashMap", CLASS_HashMap, CFLAG_HashMap, STRUCT_HashMap, CLASS_Object, 0, 8, 0, knh_HashMap_fdefault},
@@ -640,7 +640,7 @@ static knh_ClassData_t ClassData[] = {
 	{"konoha.ExceptionHandler", CLASS_ExceptionHandler, CFLAG_ExceptionHandler, STRUCT_ExceptionHandler, CLASS_Object, 0, 0, 0, knh_ExceptionHandler_fdefault},
 	{"konoha.Script", CLASS_Script, CFLAG_Script, STRUCT_Script, CLASS_Object, 0, 10, 0, knh_Script_fdefault},
 	{"konoha.NameSpace", CLASS_NameSpace, CFLAG_NameSpace, STRUCT_NameSpace, CLASS_Object, 0, 0, 0, knh_NameSpace_fdefault},
-	{"konoha.System", CLASS_System, CFLAG_System, STRUCT_System, CLASS_Object, 0, 14, 0, knh_System_fdefault},
+	{"konoha.System", CLASS_System, CFLAG_System, STRUCT_System, CLASS_Object, 0, 15, 0, knh_System_fdefault},
 	{"konoha.Context", CLASS_Context, CFLAG_Context, STRUCT_Context, CLASS_Object, 0, 16, 0, knh_Context_fdefault},
 	{"konoha.Token", CLASS_Token, CFLAG_Token, STRUCT_Token, CLASS_Object, 0, 3, 0, knh_Token_fdefault},
 	{"konoha.Stmt", CLASS_Stmt, CFLAG_Stmt, STRUCT_Stmt, CLASS_Object, 0, 2, 0, knh_Stmt_fdefault},
@@ -878,6 +878,7 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"size", FIELDN_size},
 	{"sort", FIELDN_sort},
 	{"split", FIELDN_split},
+	{"stackdump", FIELDN_stackdump},
 	{"startsWith", FIELDN_startsWith},
 	{"status", FIELDN_status},
 	{"stdErr", FIELDN_stdErr},
@@ -912,7 +913,7 @@ static knh_FieldNameData_t FieldNameData[] = {
 static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_nThis_Int, 1+ 0, NNTYPE_This, TYPE_Int, FIELDN_i},
 	{MFN_nThis_nInt, 1+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_n},
-	{MFN_nThis_nAny1_, 1+ 0, NNTYPE_This, NNTYPE_Any1, FIELDN_v},
+	{MFN_nThis_Any1_, 1+ 0, NNTYPE_This, TYPE_Any1, FIELDN_v},
 	{MFN_nThis_nInt_, 1+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_v},
 	{MFN_nThis_nFloat_, 1+ 0, NNTYPE_This, NNTYPE_Float, FIELDN_v},
 	{MFN_void_nAny1, 1+ 0, TYPE_void, NNTYPE_Any1, FIELDN_v},
@@ -963,7 +964,6 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_Float_nAny, 1+ 0, TYPE_Float, NNTYPE_Any, FIELDN_n},
 	{MFN_String_nAny, 1+ 0, TYPE_String, NNTYPE_Any, FIELDN_n},
 	{MFN_Any_nAny, 1+ 0, TYPE_Any, NNTYPE_Any, FIELDN_n},
-	{MFN_nThis_Any1_, 1+ 0, NNTYPE_This, TYPE_Any1, FIELDN_v},
 	{MFN_Any1_nString, 1+ 0, TYPE_Any1, NNTYPE_String, FIELDN_k},
 	{MFN_nBoolean_nString, 1+ 0, NNTYPE_Boolean, NNTYPE_String, FIELDN_k},
 	{MFN_void_nString_Any1, 2+ 0, TYPE_void, NNTYPE_String, FIELDN_k, TYPE_Any1, FIELDN_v},
@@ -1023,7 +1023,7 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 static knh_MethodData_t MethodData[] = {
 	{knh__Array_new, 0, CLASS_Array, METHODN_new, 0, MFN_nThis_Int, (void*)NULL},
 	{knh__Array_new__array, 0, CLASS_Array, METHODN_new__array, 0, MFN_nThis_nInt, (void*)NULL},
-	{knh__Array_new__init, KNH_FLAG_MF_VARARGS, CLASS_Array, METHODN_new__init, 0, MFN_nThis_nAny1_, (void*)NULL},
+	{knh__Array_new__init, KNH_FLAG_MF_VARARGS, CLASS_Array, METHODN_new__init, 0, MFN_nThis_Any1_, (void*)NULL},
 	{knh__IArray_new, 0, CLASS_IArray, METHODN_new, 0, MFN_nThis_Int, (void*)NULL},
 	{knh__IArray_new__array, 0, CLASS_IArray, METHODN_new__array, 0, MFN_nThis_nInt, (void*)NULL},
 	{knh__IArray_new__init, KNH_FLAG_MF_VARARGS, CLASS_IArray, METHODN_new__init, 0, MFN_nThis_nInt_, (void*)NULL},
@@ -1089,7 +1089,6 @@ static knh_MethodData_t MethodData[] = {
 	{knh__FArray_set2D, 0, CLASS_FArray, METHODN_set2D, 0, MFN_void_nInt_nInt_nFloat, (void*)NULL},
 	{knh__FArray_set3D, 0, CLASS_FArray, METHODN_set3D, 0, MFN_void_nInt_nInt_nInt_nFloat, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_Iterator, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Iterator__k},
-	{knh_fmethod_movableText, 0, CLASS_Iterator, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Iterator__dump},
 	{knh__Bytes_new, 0, CLASS_Bytes, METHODN_new, 0, MFN_nBytes_Int, (void*)NULL},
 	{knh__Bytes_putc, 0, CLASS_Bytes, METHODN_putc, 0, MFN_void_nInt, (void*)NULL},
 	{knh__Bytes_write, 0, CLASS_Bytes, METHODN_write, 0, MFN_void_nBytes_Int_Int, (void*)NULL},
@@ -1327,6 +1326,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Script_readLine, 0, CLASS_Script, METHODN_readLine, 0, MFN_String_String, (void*)NULL},
 	{knh__Script_addHistory, 0, CLASS_Script, METHODN_addHistory, 0, MFN_void_nString, (void*)NULL},
 	{knh__System_gc, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_gc, 0, MFN_void, (void*)NULL},
+	{knh__System_stackdump, 0, CLASS_System, METHODN_stackdump, 0, MFN_void, (void*)NULL},
 	{knh__Object_opInstanceof, 0, CLASS_Object, METHODN_opInstanceof, 0, MFN_Boolean_nClass, (void*)NULL},
 	{knh__Object_isRelease, 0, CLASS_Object, METHODN_isRelease, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Object_isDebug, 0, CLASS_Object, METHODN_isDebug, 0, MFN_nBoolean, (void*)NULL},
