@@ -205,7 +205,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 
 #define VM_PUSH__DEF(ctx, cid) \
 	((Context*)ctx)->esp++; \
-	KNH_SETv(ctx, ((Context*)ctx)->esp[0].o, knh_tClass_defaultValue(ctx, CLASS_type(cid))); \
+	KNH_SETv(ctx, ((Context*)ctx)->esp[0].o, knh_ClassTable_defaultValue(ctx, CLASS_type(cid))); \
 
 #define KNH_SYS_CTX    0
 #define KNH_SYS_STDIN  1
@@ -273,7 +273,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 #define VM_CALL(ctx, n, mn) { \
 		KNH_CHECKSTACK(ctx); \
 		knh_sfp_t *mbp_ = ctx->esp - (n) ; \
-		KNH_SETv(ctx, mbp_[0].o, knh_Method_ufind(ctx, knh_Object_cid(mbp_[1].o), mn)); \
+		KNH_SETv(ctx, mbp_[0].o, konoha_lookupMethod(ctx, knh_Object_cid(mbp_[1].o), mn)); \
 		KNH_ASSERT(IS_Method(mbp_[0].mtd)); \
 		mbp_[0].op = (knh_stackop_t)pc; \
 		(mbp_[0].mtd)->fcall_1(ctx, mbp_ + 1); \
@@ -284,7 +284,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 #define VM_DCALL(ctx, n, mn) { \
 		KNH_CHECKSTACK(ctx); \
 		knh_sfp_t *mbp_ = ((Context*)ctx)->esp - (n) ; \
-		KNH_SETv(ctx, mbp_[0].o, knh_Method_ufind(ctx, knh_Object_cid(mbp_[1].o), mn)); \
+		KNH_SETv(ctx, mbp_[0].o, konoha_lookupMethod(ctx, knh_Object_cid(mbp_[1].o), mn)); \
 		KNH_ASSERT(IS_Method(mbp_[0].mtd)); \
 		mbp_[0].op = (knh_stackop_t)pc; \
 		knh_dynamiccall(ctx, mbp_); \
