@@ -89,6 +89,12 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 		sfp[(n2)] = temp;\
 	}\
 
+#define KNH_SETESP(ctx, sfp, n) \
+	((Context*)ctx)->esp = &(sfp[n]);\
+	if(unlikely((ctx)->stacksize - ((ctx)->esp - (ctx)->stack) < KNH_LOCALSIZE)) {\
+		KNH_THROWs(ctx, "StackOverflow!!"); \
+	}\
+
 /* ======================================================================== */
 
 #define KLR_HALT(ctx) KNH_THROWs(ctx, "Halt!!")
@@ -233,12 +239,12 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 /* ------------------------------------------------------------------------ */
 
 #define KLR_BOX(ctx, n, cid) {\
-		KLR_MOV(ctx, sfp[n].o, knh_boxing(ctx, &sfp[n], cid));\
+		KLR_MOV(ctx, sfp[n].o, new_Object_boxing(ctx, cid, &sfp[n]));\
 	}\
 
 #define KLR_BOXnc(ctx, n, cid) \
 	if(IS_NOTNULL(sfp[n].o)){ \
-		KLR_MOV(ctx, sfp[n].o, knh_boxing(ctx, &sfp[n], cid));\
+		KLR_MOV(ctx, sfp[n].o, new_Object_boxing(ctx, cid, &sfp[n]));\
 	}\
 
 #define KLR_NNBOX(ctx, n, cid) {\
@@ -432,6 +438,7 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 /* ------------------------------------------------------------------------- */
 
 #define KLR_TOSTRf(ctx, n, mn, fmt) { \
+		DBG2_ASSERT(ctx->esp <= (sfp + n));\
 		KLR_SWAP(ctx, n, n+1); \
 		knh_cwb_t cwb = new_cwb(ctx);\
 		KLR_MOV(ctx, sfp[n+2].o, cwb.w);\
@@ -955,8 +962,8 @@ int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 /* ------------------------------------------------------------------------ */
 /* ------------------------------------------------------------------------ */
 
-
 #define KNH_LOCAL(ctx)  ((Context*)ctx)->esp
+#define KNH_SHIFTESP(ctx, newesp)  ((Context*)ctx)->esp = (newesp)
 #define KNH_LOCALBACK(ctx, lsfp)  ((Context*)ctx)->esp = lsfp
 
 #define KNH_LPUSH(ctx, v)  {\
