@@ -71,7 +71,7 @@ static METHOD knh__Array_new__array(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[VARARGS] This! Array.new:init(Any1! value) @VARARGS */
+/* @method[VARARGS] This! Array.new:init(Any1 value) @VARARGS */
 
 static METHOD knh__Array_new__init(Ctx *ctx, knh_sfp_t *sfp)
 {
@@ -1253,41 +1253,21 @@ static METHOD knh__FArray_set3D(Ctx *ctx, knh_sfp_t *sfp)
 
 void knh_Iterator__k(Ctx *ctx, Iterator *o, OutputStream *w, String *m)
 {
-	knh_putc(ctx, w, '[');
 	size_t c = 0;
 	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
 	KNH_MOV(ctx, lsfp[0].o, o);
-	o->fnext_1(ctx, lsfp, 1);
-	while(HAS_ITRNEXT(lsfp[1].o)) {
+	KNH_SHIFTESP(ctx, lsfp+3);
+	o->fnext_1(ctx, lsfp, 2);
+	while(HAS_ITRNEXT(lsfp[2].o)) {
 		if(c > 0) {
-			knh_write_delim(ctx,w);
+			knh_write_EOL(ctx,w);
 		}
-		knh_sfp_format(ctx, lsfp+1, METHODN__k, w, KNH_NULL);
+		KNH_SHIFTESP(ctx, lsfp+1);
+		knh_esp1_format(ctx, METHODN__k, w, KNH_NULL);
 		c++;
-		o->fnext_1(ctx, lsfp, 1);
+		KNH_SHIFTESP(ctx, lsfp+3);
+		o->fnext_1(ctx, lsfp, 2);
 	}
-	knh_putc(ctx, w, ']');
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method void Iterator.%dump(OutputStream w, String m) */
-
-void knh_Iterator__dump(Ctx *ctx, Iterator *o, OutputStream *w, String *m)
-{
-	knh_putc(ctx, w, '[');
-	size_t c = 0;
-	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
-	KNH_MOV(ctx, lsfp[0].o, o);
-	o->fnext_1(ctx, lsfp, 1);
-	while(HAS_ITRNEXT(lsfp[1].o)) {
-		if(c > 0) {
-			knh_write_delim(ctx,w);
-		}
-		knh_sfp_format(ctx, lsfp+1, METHODN__k, w, KNH_NULL);
-		c++;
-		o->fnext_1(ctx, lsfp, 1);
-	}
-	knh_putc(ctx, w, ']');
 }
 
 /* ------------------------------------------------------------------------ */
