@@ -149,7 +149,7 @@ static METHOD knh__Int_opLand(Ctx *ctx, knh_sfp_t *sfp)
 {
 	int ac = knh_sfp_argc(ctx, sfp + 1);
 	knh_sfp_t *v = sfp + 1;
-	knh_integer_t n = p_integer(sfp[0]);
+	knh_int_t n = p_integer(sfp[0]);
 	size_t i;
 	for(i = 0; i < ac; i++) {
 		n = n & p_integer(v[i]);
@@ -164,7 +164,7 @@ static METHOD knh__Int_opLor(Ctx *ctx, knh_sfp_t *sfp)
 {
 	int ac = knh_sfp_argc(ctx, sfp + 1);
 	knh_sfp_t *v = sfp + 1;
-	knh_integer_t n = p_integer(sfp[0]);
+	knh_int_t n = p_integer(sfp[0]);
 	size_t i;
 	for(i = 0; i < ac; i++) {
 		n = n | p_integer(v[i]);
@@ -229,7 +229,7 @@ static METHOD knh__Int_opSize(Ctx *ctx, knh_sfp_t *sfp)
 		KNH_RETURN_Int(ctx, sfp, 0);
 	}
 	else {
-		knh_integer_t n = p_integer(sfp[0]);
+		knh_int_t n = p_integer(sfp[0]);
 		if(n >= 0) {
 			KNH_RETURN_Int(ctx, sfp, n);
 		}
@@ -244,9 +244,9 @@ static METHOD knh__Int_opSize(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__Int_random(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_integer_t n = knh_rand();
+	knh_int_t n = knh_rand();
 	if(IS_NOTNULL(sfp[1].o)) {
-		knh_integer_t max = p_integer(sfp[1]);
+		knh_int_t max = p_integer(sfp[1]);
 		if(max > 0) {
 			KNH_RETURN_Int(ctx, sfp,  n % max);
 		}
@@ -375,7 +375,7 @@ static METHOD knh__Float_opSize(Ctx *ctx, knh_sfp_t *sfp)
 		KNH_RETURN_Int(ctx, sfp, 0);
 	}
 	else {
-		knh_uinteger_t n = (knh_uinteger_t)p_float(sfp[0]);
+		knh_uint_t n = (knh_uint_t)p_float(sfp[0]);
 		KNH_RETURN_Int(ctx, sfp, n);
 	}
 }
@@ -411,7 +411,7 @@ static METHOD knh__Boolean__k(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__Int__s(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_write_integerfmt(ctx, sfp[1].w, KNH_INTEGER_FMT, sfp[0].ivalue);
+	knh_write_integerfmt(ctx, sfp[1].w, KNH_INT_FMT, sfp[0].ivalue);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -419,7 +419,7 @@ static METHOD knh__Int__s(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__Int__k(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_write_integerfmt(ctx, sfp[1].w, KNH_INTEGER_FMT, sfp[0].ivalue);
+	knh_write_integerfmt(ctx, sfp[1].w, KNH_INT_FMT, sfp[0].ivalue);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -429,11 +429,11 @@ static METHOD knh__Int__d(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_String(sfp[2].s)) {
 		char fmt[40];
-		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(sfp[2].s), 0, KNH_INTEGER_FMT);
+		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(sfp[2].s), 0, KNH_INT_FMT);
 		knh_write_integerfmt(ctx, sfp[1].w, fmt, sfp[0].ivalue);
 	}
 	else {
-		knh_write_integerfmt(ctx, sfp[1].w, KNH_INTEGER_FMT, sfp[0].ivalue);
+		knh_write_integerfmt(ctx, sfp[1].w, KNH_INT_FMT, sfp[0].ivalue);
 	}
 }
 
@@ -444,11 +444,11 @@ static METHOD knh__Int__u(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_String(sfp[2].s)) {
 		char fmt[40];
-		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(sfp[2].s), 0, KNH_UINTEGER_FMT);
+		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(sfp[2].s), 0, KNH_UINT_FMT);
 		knh_write_integerfmt(ctx, sfp[1].w, fmt, sfp[0].ivalue);
 	}
 	else {
-		knh_write_integerfmt(ctx, sfp[1].w, KNH_UINTEGER_FMT, sfp[0].ivalue);
+		knh_write_integerfmt(ctx, sfp[1].w, KNH_UINT_FMT, sfp[0].ivalue);
 	}
 }
 
@@ -472,7 +472,7 @@ static METHOD knh__Int__f(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__Int__x(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_write_integerfmt(ctx, sfp[1].w, KNH_INTEGER_XFMT, sfp[0].ivalue);
+	knh_write_integerfmt(ctx, sfp[1].w, KNH_INT_XFMT, sfp[0].ivalue);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -500,7 +500,7 @@ void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, size_t bits)
 
 static METHOD knh__Int__bits(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_write_bits(ctx, sfp[1].w, sfp[0].ivalue, sizeof(knh_integer_t) * 8);
+	knh_write_bits(ctx, sfp[1].w, sfp[0].ivalue, sizeof(knh_int_t) * 8);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -519,12 +519,12 @@ static METHOD knh__Float__d(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_String(sfp[2].s)) {
 		char fmt[40];
-		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(sfp[2].s), 0, KNH_INTEGER_FMT);
+		knh_format_newFMT(fmt, sizeof(fmt), knh_String_tobytes(sfp[2].s), 0, KNH_INT_FMT);
 		//DBG_P("fmt='%s'", fmt);
-		knh_write_integerfmt(ctx, sfp[1].w, fmt, (knh_integer_t)p_float(sfp[0]));
+		knh_write_integerfmt(ctx, sfp[1].w, fmt, (knh_int_t)p_float(sfp[0]));
 	}
 	else {
-		knh_write_integerfmt(ctx, sfp[1].w, KNH_INTEGER_FMT, (knh_integer_t)p_float(sfp[0]));
+		knh_write_integerfmt(ctx, sfp[1].w, KNH_INT_FMT, (knh_int_t)p_float(sfp[0]));
 	}
 }
 
@@ -558,7 +558,7 @@ static METHOD knh__Float__bits(Ctx *ctx, knh_sfp_t *sfp)
 static METHOD knh__Float__k(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Float *o = sfp[0].f;
-	FloatUnit *u = (FloatUnit*)ctx->tClass[o->h.cid].cspec;
+	FloatUnit *u = (FloatUnit*)ctx->share->ClassTable[o->h.cid].cspec;
 	KNH_ASSERT(IS_FloatUnit(u));
 	knh_write__ffmt(ctx, sfp[1].w, DP(u)->FMT, p_float(sfp[0]));
 	knh_bytes_t tag = knh_String_tobytes(DP(u)->spec.tag);
@@ -597,7 +597,7 @@ static MAPPER knh_String_Boolean(Ctx *ctx, knh_sfp_t *sfp)
 
 static MAPPER knh_String_Int(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_integer_t v = 0;
+	knh_int_t v = 0;
 	if(knh_bytes_parseinteger(knh_String_tobytes(sfp[0].s), &v)) {
 		KNH_MAPPED_Int(ctx, sfp, v);
 	}
@@ -610,7 +610,7 @@ static MAPPER knh_String_Int(Ctx *ctx, knh_sfp_t *sfp)
 static MAPPER knh_Int_String(Ctx *ctx, knh_sfp_t *sfp)
 {
 	char buf[256];
-	knh_snprintf(buf, sizeof(buf), KNH_INTEGER_FMT, sfp[0].ivalue);
+	knh_snprintf(buf, sizeof(buf), KNH_INT_FMT, sfp[0].ivalue);
 	KNH_MAPPED(ctx, sfp, new_String(ctx, B(buf), NULL));
 }
 
@@ -652,7 +652,7 @@ static MAPPER knh_Int_Float(Ctx *ctx, knh_sfp_t *sfp)
 
 static MAPPER knh_Float_Int(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_integer_t v = (knh_integer_t)sfp[0].fvalue;
+	knh_int_t v = (knh_int_t)sfp[0].fvalue;
 	KNH_MAPPED_Int(ctx, sfp, v);
 }
 
