@@ -144,7 +144,8 @@ static METHOD knh__OutputStream_print(Ctx *ctx, knh_sfp_t *sfp)
 		knh_OutputStream_print_(ctx, sfp[0].w, knh_String_tobytes(sfp[1].s), 0);
 	}
 	else {
-		knh_sfp_format(ctx, sfp+1, METHODN__s, sfp[0].w, KNH_NULL);
+		KNH_SHIFTESP(ctx, sfp);
+		knh_esp1_format(ctx, METHODN__s, sfp[0].w, KNH_NULL);
 	}
 	KNH_RETURN_void(ctx, sfp);
 }
@@ -158,8 +159,10 @@ static METHOD knh__OutputStream_println(Ctx *ctx, knh_sfp_t *sfp)
 		knh_OutputStream_print_(ctx, sfp[0].w, knh_String_tobytes(sfp[1].s), 1);
 	}
 	else {
-		knh_sfp_format(ctx, sfp+1, METHODN__s, sfp[0].w, KNH_NULL);
-		knh_write_EOL(ctx, sfp[0].w);
+		KNH_SHIFTESP(ctx, sfp);
+		knh_esp1_format(ctx, METHODN__s, sfp[0].w, KNH_NULL);
+		KNH_ASSERT(IS_OutputStream(sfp[2].o)); // Tricky ..
+		knh_write_EOL(ctx, sfp[2].w);
 	}
 	KNH_RETURN_void(ctx, sfp);
 }
@@ -189,7 +192,8 @@ static METHOD knh__OutputStream_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 			}
 		}
 		else {
-			knh_sfp_format(ctx, v + i, METHODN__s, out, KNH_NULL);
+			KNH_SHIFTESP(ctx, sfp + i); // Trickey
+			knh_esp1_format(ctx, METHODN__s, out, KNH_NULL);
 		}
 	}
 	if(knh_OutputStream_isAutoFlush(out)) {
