@@ -114,8 +114,26 @@ static METHOD knh__String_opSize(Ctx *ctx, knh_sfp_t *sfp)
 static METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_cwb_t cwb = new_cwb(ctx);
-	knh_sfp_format(ctx, sfp, METHODN__s, cwb.w, KNH_NULL);
-	knh_sfp_format(ctx, sfp+1, METHODN__s, cwb.w, KNH_NULL);
+//	if(IS_bString(sfp[0].o)) {
+//		knh_Bytes_write(ctx, cwb.ba, knh_String_tobytes(sfp[0].s));
+//	}
+//	else {
+//		KNH_SETESP(ctx, sfp, 2);
+//		knh_sfp_format(ctx, sfp, METHODN__s, cwb.w, KNH_NULL);
+//	}
+//	if(IS_bString(sfp[1].o)) {
+//		knh_Bytes_write(ctx, cwb.ba, knh_String_tobytes(sfp[1].s));
+//	}
+//	else {
+//		KNH_SETESP(ctx, sfp, 2);
+//		knh_sfp_format(ctx, sfp+1, METHODN__s, cwb.w, KNH_NULL);
+//	}
+	knh_sfp_t *esp = KNH_LOCAL(ctx);
+	KNH_SETv(ctx, esp[1].o, sfp[0].o); esp[1].data = sfp[0].data;
+	knh_esp1_format(ctx, METHODN__s, cwb.w, KNH_NULL);
+	KNH_ASSERT(esp == ctx->esp);
+	KNH_SETv(ctx, esp[1].o, sfp[1].o); esp[1].data = sfp[1].data;
+	knh_esp1_format(ctx, METHODN__s, cwb.w, KNH_NULL);
 	KNH_RETURN(ctx, sfp, new_String__cwb(ctx, cwb));
 }
 
@@ -124,13 +142,18 @@ static METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__String_concat(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_sfp_t *v = sfp + 1;
-	int ac = knh_sfp_argc(ctx, v);
-	size_t i;
+	int i, ac = knh_sfp_argc(ctx, sfp);
 	knh_cwb_t cwb = new_cwb(ctx);
-	knh_sfp_format(ctx, sfp, METHODN__s, cwb.w, KNH_NULL);
+	knh_sfp_t *esp = KNH_LOCAL(ctx);
 	for(i = 0; i < ac; i++) {
-		knh_sfp_format(ctx, v + i, METHODN__s, cwb.w, KNH_NULL);
+		if(IS_bString(sfp[i].o)) {
+			knh_Bytes_write(ctx, cwb.ba, knh_String_tobytes(sfp[i].s));
+		}
+		else {
+			KNH_ASSERT(esp == ctx->esp);
+			KNH_SETv(ctx, esp[1].o, sfp[i].o); esp[1].data = sfp[i].data;
+			knh_esp1_format(ctx, METHODN__s, cwb.w, KNH_NULL);
+		}
 	}
 	KNH_RETURN(ctx, sfp, new_String__cwb(ctx, cwb));
 }
@@ -287,13 +310,12 @@ static METHOD knh__String_opFmt(Ctx *ctx, knh_sfp_t *sfp)
 			goto L_ERROR;
 		}
 		if(0 <= idx && (size_t) idx < ac) {
+			knh_sfp_t *esp = KNH_LOCAL(ctx);
+			KNH_SETv(ctx, esp[1].o, v[idx].o); esp[1].data = v[idx].data;
 			mtn = knh_bytes_last(mtn, 1);
-			if(mtn.len > 0 && knh_bytes_isOptionalMT(mtn)) {
-				knh_sfp_format(ctx, v + idx, mt, cwb.w, UP(new_String(ctx, mtn, NULL)));
-			}
-			else {
-				knh_sfp_format(ctx, v + idx, mt, cwb.w, KNH_NULL);
-			}
+			Object *m = (mtn.len > 0 && knh_bytes_isOptionalMT(mtn)) ?
+					UP(new_String(ctx, mtn, NULL)) : KNH_NULL;
+			knh_esp1_format(ctx, mt, cwb.w, m);
 		}
 		else {
 			KNH_WARNING(ctx, "formatting: out of index %d < %d", (int)idx, (int)ac);
