@@ -55,7 +55,7 @@ static METHOD knh__System_setIn(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
-			KNH_SETv(ctx, DP(ctx->sys)->in, konoha_getClassDefaultValue(ctx, CLASS_InputStream));
+			KNH_SETv(ctx, DP(ctx->sys)->in, konoha_geClassTableDefaultValue(ctx, CLASS_InputStream));
 		}
 		else {
 			KNH_SETv(ctx, DP(ctx->sys)->in, sfp[1].o);
@@ -79,7 +79,7 @@ static METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
-			KNH_SETv(ctx, DP(ctx->sys)->out, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
+			KNH_SETv(ctx, DP(ctx->sys)->out, konoha_geClassTableDefaultValue(ctx, CLASS_OutputStream));
 		}
 		else {
 			KNH_SETv(ctx, DP(ctx->sys)->out, sfp[1].o);
@@ -103,7 +103,7 @@ static METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
-			KNH_SETv(ctx, DP(ctx->sys)->err, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
+			KNH_SETv(ctx, DP(ctx->sys)->err, konoha_geClassTableDefaultValue(ctx, CLASS_OutputStream));
 		}
 		else {
 			KNH_SETv(ctx, DP(ctx->sys)->err, sfp[1].o);
@@ -117,7 +117,7 @@ static METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__System_exit(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_int_t status = IS_NULL(sfp[1].o) ? 0 : p_int(sfp[1]);
+	knh_intptr_t status = IS_NULL(sfp[1].o) ? 0 : p_int(sfp[1]);
 	KNH_SECURE(ctx);
 	KNH_NOTICE(ctx, "exiting by a user");
 	exit((int)status);
@@ -208,7 +208,7 @@ static METHOD knh__Context_setIn(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
 	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->in, konoha_getClassDefaultValue(ctx, CLASS_InputStream));
+		KNH_SETv(ctx, ((Context*)ctx)->in, konoha_geClassTableDefaultValue(ctx, CLASS_InputStream));
 	}
 	else {
 		KNH_SETv(ctx, ((Context*)ctx)->in, sfp[1].o);
@@ -223,7 +223,7 @@ static METHOD knh__Context_setOut(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
 	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->out, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
+		KNH_SETv(ctx, ((Context*)ctx)->out, konoha_geClassTableDefaultValue(ctx, CLASS_OutputStream));
 	}
 	else {
 		KNH_SETv(ctx, ((Context*)ctx)->out, sfp[1].o);
@@ -238,7 +238,7 @@ static METHOD knh__Context_setErr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
 	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->err, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
+		KNH_SETv(ctx, ((Context*)ctx)->err, konoha_geClassTableDefaultValue(ctx, CLASS_OutputStream));
 	}
 	else {
 		KNH_SETv(ctx, ((Context*)ctx)->err, sfp[1].o);
@@ -267,7 +267,7 @@ static METHOD knh__Exception_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Exception *o = sfp[0].e;
 	DP(o)->eid  = EXPT_Exception;
-	DP(o)->flag = ctx->tExpt[EXPT_Exception].flag;
+	DP(o)->flag = ctx->share->ExptTable[EXPT_Exception].flag;
 
 	knh_cwb_t cwb = new_cwb(ctx);
 	knh_write__s(ctx, cwb.w, "Exception!!");
@@ -385,7 +385,7 @@ void knh_System__dump(Ctx *ctx, System *o, OutputStream *w, String *m)
 	knh_write__s(ctx, w, " thread");
 #endif
 	knh_write_USING_REGEX(ctx, w);
-	knh_printf(ctx, w, " used_memory:%d kb", (int)ctx->share->statUsedMemorySize / 1024);
+	knh_printf(ctx, w, " used_memory:%d kb", (int)ctx->stat->usedMemorySize / 1024);
 	knh_write_EOL(ctx, w);
 }
 
