@@ -54,7 +54,7 @@ size_t knh_array_newsize(size_t newsize, size_t usize)
 
 /* ------------------------------------------------------------------------ */
 
-size_t knh_array_index(Ctx *ctx, knh_int_t n, size_t size)
+size_t knh_array_index(Ctx *ctx, knh_intptr_t n, size_t size)
 {
 	size_t idx = (n < 0) ? size + n : n;
 	if(!(idx < size)) {
