@@ -131,7 +131,7 @@ HashMap* new_HashMap(Ctx *ctx, char *name, size_t capacity)
 
 knh_hashentry_t *knh_Hash_get__hcode(Ctx *ctx, knh_Hash_t *o, knh_hcode_t hcode)
 {
-	knh_uint_t h = hcode % DP(o)->hmax;
+	knh_uintptr_t h = hcode % DP(o)->hmax;
 	knh_hashentry_t *e = DP(o)->array[h];
 	while(e != NULL) {
 		if(e->hcode == hcode) return e;
@@ -144,7 +144,7 @@ knh_hashentry_t *knh_Hash_get__hcode(Ctx *ctx, knh_Hash_t *o, knh_hcode_t hcode)
 
 Object *knh_HashMap_get__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode)
 {
-	knh_uint_t h = hcode % DP((knh_Hash_t*)o)->hmax;
+	knh_uintptr_t h = hcode % DP((knh_Hash_t*)o)->hmax;
 	knh_hashentry_t *e = DP((knh_Hash_t*)o)->array[h];
 	while(e != NULL) {
 		if(e->hcode == hcode) return e->value;
@@ -155,9 +155,9 @@ Object *knh_HashMap_get__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode)
 
 /* ------------------------------------------------------------------------ */
 
-knh_uint_t knh_HashSet_get__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode)
+knh_uintptr_t knh_HashSet_get__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode)
 {
-	knh_uint_t h = hcode % DP((knh_Hash_t*)o)->hmax;
+	knh_uintptr_t h = hcode % DP((knh_Hash_t*)o)->hmax;
 	knh_hashentry_t *e = DP((knh_Hash_t*)o)->array[h];
 	while(e != NULL) {
 		if(e->hcode == hcode) return e->uvalue;
@@ -170,7 +170,7 @@ knh_uint_t knh_HashSet_get__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode)
 
 void knh_Hash_remove__hcode(Ctx *ctx, knh_Hash_t *o, knh_hcode_t hcode)
 {
-	knh_uint_t h = hcode % DP(o)->hmax;
+	knh_uintptr_t h = hcode % DP(o)->hmax;
 	knh_hashentry_t *e = DP(o)->array[h];
 	knh_hashentry_t **prev_next = &(DP(o)->array[h]);
 	while(e != NULL) {
@@ -210,7 +210,7 @@ void knh_Hash_rehash(Ctx *ctx, knh_Hash_t *o)
 			knh_hashentry_t *e = KNH_HASHENTRY(b->tables[i], esize, j);
 			if(e->key == NULL) continue;
 			e->next = NULL;
-			knh_uint_t h = e->hcode % newhmax;
+			knh_uintptr_t h = e->hcode % newhmax;
 			knh_hashentry_t **p = &(b->array[h]);
 			while(p[0] != NULL) p = &(p[0]->next);
 			p[0] = e;
@@ -233,7 +233,7 @@ void knh_HashMap_set__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode, Any *value)
 	e->hcode = hcode;
 	KNH_INITv(e->key, KNH_NULL);
 	KNH_INITv(e->value, value);
-	knh_uint_t h = hcode % DP(o)->hmax;
+	knh_uintptr_t h = hcode % DP(o)->hmax;
 	e->next = DP(o)->array[h];
 	DP(o)->array[h] = e;
 	DP(o)->size++;
@@ -241,7 +241,7 @@ void knh_HashMap_set__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode, Any *value)
 
 /* ------------------------------------------------------------------------ */
 
-void knh_HashSet_set__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode, knh_uint_t uvalue)
+void knh_HashSet_set__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode, knh_uintptr_t uvalue)
 {
 	knh_Hash_t *hash = (knh_Hash_t*)o;
 	knh_hashentry_t *e = knh_Hash_get__hcode(ctx, hash, hcode);
@@ -254,7 +254,7 @@ void knh_HashSet_set__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode, knh_uint_t
 	e->hcode = hcode;
 	KNH_INITv(e->key, KNH_NULL);
 	e->uvalue = uvalue;
-	knh_uint_t h = hcode % DP(o)->hmax;
+	knh_uintptr_t h = hcode % DP(o)->hmax;
 	e->next = DP(o)->array[h];
 	DP(o)->array[h] = e;
 	DP(o)->size++;
