@@ -105,7 +105,7 @@ knh_type_t knh_MethodField_pztype(MethodField *o, size_t n)
 		}
 		return o->mparams[o->psize - 1].type; /* last type */
 	}
-	else if(n == 0 || o->psize != 1) {
+	else if(n == 0 || o->psize != 2) {
 		return o->p0.type;  /* last type or void */
 	}else {
 		DBG2_ASSERT(n == 1 && o->psize == 2);
@@ -123,7 +123,7 @@ knh_mparam_t knh_MethodField_param(MethodField *o, size_t n)
 		}
 		return o->mparams[o->psize - 1]; /* last param */
 	}
-	else if(n == 0 || o->psize != 1) {
+	else if(n == 0 || o->psize != 2) {
 		return o->p0;  /* last type or void */
 	}else {
 		DBG2_ASSERT(n == 1 && o->psize == 2);
@@ -702,22 +702,21 @@ knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool
 Method *konoha_lookupMethod(Ctx *ctx, knh_class_t cid, knh_methodn_t mn)
 {
 	KNH_ASSERT(!METHODN_IS_MOVTEXT(mn));
-	DBG2_({
-		char bufcm[CLASSNAME_BUFSIZ];
-		knh_format_cmethodn(ctx, bufcm, sizeof(bufcm), cid, mn);
-		DBG2_P("finding ..: %s", bufcm);
-	})
 	knh_hcode_t h = ((((knh_hcode_t)cid) << (sizeof(knh_class_t) * 8)) + mn) % ctx->cachesize;
 	Method *mtd = ctx->mtdCache[h];
 	if(mtd != NULL) {
 		if(DP(mtd)->mn == mn) {
-			if(DP(mtd)->cid != cid) {
-				DBG2_P("Polymorphic Caching?? %s %s", CLASSN(DP(mtd)->cid), CLASSN(cid));
+			if(DP(mtd)->cid == cid || knh_class_instanceof(ctx, cid, DP(mtd)->cid)) {
+				knh_stat_mtdCacheHit(ctx);
+				return mtd;
 			}
-			knh_stat_mtdCacheHit(ctx);
-			return mtd;
 		}
 		knh_stat_mtdCacheMiss(ctx);
+		DBG2_({
+			char bufcm[CLASSNAME_BUFSIZ];
+			knh_format_cmethodn(ctx, bufcm, sizeof(bufcm), cid, mn);
+			DBG2_P("Cache missed. looking up %s", bufcm);
+		})
 	}
 	mtd = knh_Class_findMethod(ctx, cid, mn);
 	ctx->mtdCache[h] = mtd;
@@ -729,22 +728,21 @@ Method *konoha_lookupMethod(Ctx *ctx, knh_class_t cid, knh_methodn_t mn)
 Method *konoha_lookupFormatter(Ctx *ctx, knh_class_t cid, knh_methodn_t mn)
 {
 	KNH_ASSERT(METHODN_IS_MOVTEXT(mn));
-//	DBG2_({
-//		char bufcm[CLASSNAME_BUFSIZ];
-//		knh_format_cmethodn(bufcm, sizeof(bufcm), cid, mn);
-//		DBG2_P("finding ..: %s", bufcm);
-//	})
 	knh_hcode_t h = ((((knh_hcode_t)cid) << (sizeof(knh_class_t) * 8)) + mn) % ctx->cachesize;
 	Method *mtd = ctx->fmtCache[h];
 	if(mtd != NULL) {
 		if(DP(mtd)->mn == mn) {
-			if(DP(mtd)->cid != cid) {
-				DBG2_P("Polymorphic Caching?? %s %s", CLASSN(DP(mtd)->cid), CLASSN(cid));
+			if(DP(mtd)->cid == cid || knh_class_instanceof(ctx, cid, DP(mtd)->cid)) {
+				knh_stat_fmtCacheHit(ctx);
+				return mtd;
 			}
-			knh_stat_fmtCacheHit(ctx);
-			return mtd;
 		}
 		knh_stat_fmtCacheMiss(ctx);
+		DBG2_({
+			char bufcm[CLASSNAME_BUFSIZ];
+			knh_format_cmethodn(ctx, bufcm, sizeof(bufcm), cid, mn);
+			DBG2_P("Cache missed. looking up %s", bufcm);
+		})
 	}
 	mtd = knh_Class_findMethod(ctx, cid, mn);
 	ctx->fmtCache[h] = mtd;
@@ -753,8 +751,6 @@ Method *konoha_lookupFormatter(Ctx *ctx, knh_class_t cid, knh_methodn_t mn)
 
 /* ------------------------------------------------------------------------ */
 
-
-
 #ifdef __cplusplus
 }
 #endif
