@@ -47,30 +47,30 @@ knh_class_t knh_system_loadVocabulary(Ctx *ctx, knh_bytes_t urn);
 
 NameSpace* new_NameSpace(Ctx *ctx, NameSpace *parent, String *nsname)
 {
-	knh_NameSpace_t* o = (NameSpace*)new_Object_bcid(ctx, CLASS_NameSpace, 0);
-	KNH_SETv(ctx, DP(o)->nsname, nsname);
+	knh_NameSpace_t* o = (NameSpace*)new_Object_bcid(ctx, CLASS_NameSpace, KNH_OBJECT_RAWINIT);
+	//DBG2_P("@@@@@@@@ %p, %p %p", o, DP(o), DP(o)->nsname);
+	KNH_INITv(DP(o)->nsname, nsname);
+	KNH_INITv(DP(o)->parent, parent);
 	if(IS_NULL(parent)) {
-		KNH_SETv(ctx, DP(o)->name2cidDictSet, new_DictSet(ctx, KONOHA_TCLASS_SIZE));
+		KNH_INITv(DP(o)->name2cidDictSet, new_DictSet(ctx, KONOHA_TCLASS_SIZE));
 	}
 	else{
-		KNH_SETv(ctx, DP(o)->parent, parent);
-		KNH_SETv(ctx, DP(o)->name2cidDictSet, new_DictSet(ctx, 64));
+		KNH_INITv(DP(o)->name2cidDictSet, new_DictSet(ctx, 64));
 		knh_NameSpace_import(ctx, o, STEXT("konoha"));
 	}
 	return o;
 }
 
-
 /* ======================================================================== */
 /* [class] */
 
-/* @ method void NameSpace.setClass(String name, Class c) */
+/* @ method void NameSpace.seClassTable(String name, Class c) */
 
-void knh_NameSpace_setClass(Ctx *ctx, NameSpace *o, String *name, knh_class_t c)
+void knh_NameSpace_seClassTable(Ctx *ctx, NameSpace *o, String *name, knh_class_t c)
 {
 	KNH_ASSERT(IS_NameSpace(o));
 	KNH_ASSERT(IS_String(name));
-	knh_DictSet_set(ctx, DP(o)->name2cidDictSet, name, (knh_uint_t)(c+1));
+	knh_DictSet_set(ctx, DP(o)->name2cidDictSet, name, (knh_uintptr_t)(c+1));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -99,9 +99,9 @@ knh_bytes_t knh_NameSpace_firstType(Ctx *ctx, NameSpace *o, knh_bytes_t name, kn
 
 
 /* ------------------------------------------------------------------------ */
-/* @ method Class NameSpace.getClass(String name) */
+/* @ method Class NameSpace.geClassTable(String name) */
 
-knh_class_t knh_NameSpace_getClass(Ctx *ctx, NameSpace *o, knh_bytes_t name)
+knh_class_t knh_NameSpace_geClassTable(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 {
 	if(knh_bytes_equals(name, STEXT("Script")) && IS_NOTNULL(DP(o)->script)) {
 		return knh_Object_cid(DP(o)->script);
@@ -113,7 +113,7 @@ knh_class_t knh_NameSpace_getClass(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 	{
 		NameSpace *ns = o;
 		while(1) {
-			knh_uint_t cid = knh_DictSet_get__b(DP(ns)->name2cidDictSet, name);
+			knh_uintptr_t cid = knh_DictSet_get__b(DP(ns)->name2cidDictSet, name);
 			if(cid > 0) return (knh_class_t)(cid-1);
 			if(IS_NULL(DP(ns)->parent)) {
 				goto L_GENPART;
@@ -126,10 +126,10 @@ knh_class_t knh_NameSpace_getClass(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 	if(o != knh_rootNameSpace) {
 		knh_index_t loc = knh_bytes_index(name, '<');
 		if(loc > 0) {
-			knh_class_t bcid = knh_NameSpace_getClass(ctx, o, knh_bytes_first(name, loc));
+			knh_class_t bcid = knh_NameSpace_geClassTable(ctx, o, knh_bytes_first(name, loc));
 			KNH_ASSERT_cid(bcid);
 			if(!knh_Class_isGenerics(bcid)) return bcid;
-			knh_class_t p1 = CLASS_Any, p2 = ctx->tClass[bcid].p2;
+			knh_class_t p1 = CLASS_Any, p2 = ctx->share->ClassTable[bcid].p2;
 			name = knh_NameSpace_firstType(ctx, o, knh_bytes_last(name, loc+1), &p1);
 			knh_NameSpace_firstType(ctx, o, name, &p2);
 			return knh_class_Generics(ctx, bcid, CLASS_type(p1), CLASS_type(p2));
@@ -153,7 +153,7 @@ void knh_NameSpace_setLocalName(Ctx *ctx, NameSpace *o, knh_class_t cid)
 {
 	KNH_ASSERT(IS_NameSpace(o));
 	KNH_ASSERT_cid(cid);
-	knh_DictSet_set(ctx, DP(o)->name2cidDictSet, ctx->tClass[cid].sname, (knh_uint_t)(cid+1));
+	knh_DictSet_set(ctx, DP(o)->name2cidDictSet, ctx->share->ClassTable[cid].sname, (knh_uintptr_t)(cid+1));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -161,14 +161,14 @@ void knh_NameSpace_setLocalName(Ctx *ctx, NameSpace *o, knh_class_t cid)
 char* knh_Context_CLASSN(Ctx *ctx, knh_class_t cid)
 {
 	KNH_ASSERT_cid(cid);
-	String *name = ctx->tClass[cid].lname;
+	String *name = ctx->share->ClassTable[cid].lname;
 	if(knh_String_startsWith(name, STEXT("konoha."))) {
-		return knh_String_tochar(ctx->tClass[cid].sname);
+		return knh_String_tochar(ctx->share->ClassTable[cid].sname);
 	}
 	else {
-		knh_uint_t cid2 = knh_DictSet_get__b(DP(ctx->ns)->name2cidDictSet, knh_String_tobytes(ctx->tClass[cid].sname));
+		knh_uintptr_t cid2 = knh_DictSet_get__b(DP(ctx->ns)->name2cidDictSet, knh_String_tobytes(ctx->share->ClassTable[cid].sname));
 		if(cid2 > 0 && cid == cid2 - 1) {
-			return knh_String_tochar(ctx->tClass[cid].sname);
+			return knh_String_tochar(ctx->share->ClassTable[cid].sname);
 		}
 		return CLASSN(cid);
 	}
@@ -185,11 +185,11 @@ void knh_NameSpace_import(Ctx *ctx, NameSpace *o, knh_bytes_t p)
 	if(p.buf[p.len-1] == '.') {
 		p.len--;
 	}
-	for(i = 0; i < ctx->share->tClassSize; i++) {
-		if(ctx->tClass[i].cspec == NULL) continue;
-		KNH_ASSERT(IS_bString(ctx->tClass[i].lname));
+	for(i = 0; i < ctx->share->ClassTableSize; i++) {
+		if(ctx->share->ClassTable[i].cspec == NULL) continue;
+		KNH_ASSERT(IS_bString(ctx->share->ClassTable[i].lname));
 		if(knh_class_isPrivate(i)) continue;
-		knh_bytes_t cname = knh_String_tobytes(ctx->tClass[i].lname);
+		knh_bytes_t cname = knh_String_tobytes(ctx->share->ClassTable[i].lname);
 		if(knh_bytes_startsWith(cname, p) && cname.buf[p.len] == '.' && isupper(cname.buf[p.len+1])) {
 			knh_NameSpace_setLocalName(ctx, o, (knh_class_t)i);
 		}
@@ -219,11 +219,11 @@ knh_type_t knh_NameSpace_getType(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 	if(knh_bytes_isNotNullType(name)) {
 		knh_class_t cid;
 		name.len--;
-		cid = knh_NameSpace_getClass(ctx, o, name);
+		cid = knh_NameSpace_geClassTable(ctx, o, name);
 		return (cid == CLASS_unknown) ? cid : NNTYPE_cid(cid);
 	}
 	else {
-		return knh_NameSpace_getClass(ctx, o, name);
+		return knh_NameSpace_geClassTable(ctx, o, name);
 	}
 }
 
@@ -234,7 +234,7 @@ knh_class_t knh_tclass_classURN(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn)
 {
 	char buf[CLASSNAME_BUFSIZ];
 	knh_snprintf(buf, sizeof(buf), KNH_CLASSSPEC_FMT, CLASSN(bcid), urn.buf);
-	knh_class_t cid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, B(buf));
+	knh_class_t cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, B(buf));
 	if(cid == CLASS_unknown) {
 		cid = knh_tclass_loadURN(ctx, bcid, urn);
 	}
@@ -266,11 +266,11 @@ knh_type_t knh_NameSpace_tagcid(Ctx *ctx, NameSpace *o, knh_class_t bcid, knh_by
 	//	char buf[CLASSNAME_BUFSIZ];
 //	DBG2_P("%s:'%s'", CLASSN(bcid), tag.buf);
 //	knh_snprintf(buf, sizeof(buf), "%s:%s", CLASSN(bcid), tag.buf);
-//	knh_class_t cid = knh_NameSpace_getClass(ctx, o, B(buf));
+//	knh_class_t cid = knh_NameSpace_geClassTable(ctx, o, B(buf));
 //	if(cid == CLASS_unknown) {
 //		if(bcid == CLASS_Int) {
 //			knh_snprintf(buf, sizeof(buf), "Float:%s", tag.buf);
-//			cid = knh_NameSpace_getClass(ctx, o, B(buf));
+//			cid = knh_NameSpace_geClassTable(ctx, o, B(buf));
 //		}
 //	}
 //	return cid;
@@ -286,7 +286,7 @@ void knh_NameSpace_setFuncClass(Ctx *ctx, NameSpace *o, knh_methodn_t mn, knh_cl
 	if(IS_NULL(DP(o)->func2cidDictSet)) {
 		KNH_SETv(ctx, DP(o)->func2cidDictSet, new_DictSet(ctx, 16));
 	}
-	knh_DictSet_set(ctx, DP(o)->func2cidDictSet, new_String__mn(ctx, mn), (knh_uint_t)(c+1));
+	knh_DictSet_set(ctx, DP(o)->func2cidDictSet, new_String__mn(ctx, mn), (knh_uintptr_t)(c+1));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -295,7 +295,7 @@ knh_class_t
 knh_NameSpace_getFuncClass(Ctx *ctx, NameSpace *o, knh_bytes_t funcname)
 {
 	if(IS_NOTNULL(DP(o)->func2cidDictSet)) {
-		knh_uint_t cid = knh_DictSet_get__b(DP(o)->func2cidDictSet, funcname);
+		knh_uintptr_t cid = knh_DictSet_get__b(DP(o)->func2cidDictSet, funcname);
 		if(cid != 0) {
 			return (knh_class_t)(cid-1);
 		}
