@@ -504,11 +504,12 @@ int knh_Stmt_eval(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int isEval)
 		KNH_MOV(ctx, lsfp[0].o, hdr);
 		KNH_TRY(ctx, L_CATCH, lsfp, 0);
 		{
-			KNH_MOV(ctx, lsfp[2].o, scr);
-			KNH_SCALL(ctx, lsfp, 1, mtd, 0/*args*/);
+			KNH_MOV(ctx, lsfp[3].o, scr);
+			KNH_SCALL(ctx, lsfp, 2, mtd, 0/*args*/);
 			if(isExpr && !knh_Stmt_isVOID(stmt)) {
-				DBG2_P("returning %s %lld", CTXCLASSN(knh_Object_cid(lsfp[1].o)), lsfp[1].ivalue);
-				knh_sfp_format(ctx, lsfp+1, mt, KNH_STDOUT, KNH_NULL);
+				//DBG2_P("returning %s %lld", CTXCLASSN(knh_Object_cid(lsfp[1].o)), lsfp[1].ivalue);
+				((Context*)ctx)->esp = lsfp+1;
+				knh_esp1_format(ctx, mt, KNH_STDOUT, KNH_NULL);
 				knh_write_EOL(ctx, KNH_STDOUT);
 			}
 		}
