@@ -272,7 +272,7 @@ knh_bool_t knh_StmtMETA_isOverride(Ctx *ctx, Stmt *o)
 
 void knh_Stmt__s(Ctx *ctx, Stmt *o, OutputStream *w, String *m)
 {
-	knh_int_t i;
+	knh_intptr_t i;
 	knh_putc(ctx, w, '(');
 	if(SP(o)->stt != STT_OP && SP(o)->stt != STT_NEW && SP(o)->stt != STT_CALL ) {
 		knh_write__s(ctx, w, knh_stmt_tochar(SP(o)->stt));
