@@ -263,7 +263,7 @@ Token *new_Token__NAME(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t t
 /* [parse] */
 
 static
-knh_bool_t knh_Bytes_isTripleQuote(Bytes *o, knh_int_t ch)
+knh_bool_t knh_Bytes_isTripleQuote(Bytes *o, knh_intptr_t ch)
 {
 	if(o->size > 2 &&
 		o->buf[o->size-1] == ch &&
@@ -479,7 +479,7 @@ int knh_Token_toClosureType(Ctx *ctx, Token *tkt, Token *tkp)
 		c++;
 	}
 	if(c > 3) {
-		KNH_SETv(ctx, DP(tkt)->data, ctx->tClass[CLASS_Closure].sname);
+		KNH_SETv(ctx, DP(tkt)->data, ctx->share->ClassTable[CLASS_Closure].sname);
 		knh_cwb_clear(cwb);
 		return 1;
 	}
@@ -533,7 +533,7 @@ void knh_Token_join(Ctx *ctx, Token *o)
 				Token *tkn = (Token*)knh_Array_n(a, i+1);
 				if(SP(tkn)->tt == TT_BRANCET && IS_NULL(DP(tkn)->data)) {
 					SP(tk)->tt = TT_TYPEN;
-					KNH_SETv(ctx, DP(tk)->data, ctx->tClass[CLASS_Bytes].sname);
+					KNH_SETv(ctx, DP(tk)->data, ctx->share->ClassTable[CLASS_Bytes].sname);
 					if(i>0) {
 						Token *tkp = (Token*)knh_Array_n(a, i-1);
 						DP(tkp)->tt_next = TT_TYPEN;
