@@ -1440,7 +1440,7 @@ void KNH_BOX(Ctx *ctx, knh_sfp_t *sfp, knh_type_t type)
 	knh_class_t bcid = ctx->share->ClassTable[cid].bcid;
 	if(bcid == CLASS_Int || bcid == CLASS_Float || bcid == CLASS_Boolean) {
 		if(IS_NNTYPE(type) || IS_NOTNULL(sfp[0].o)) {
-			KNH_SETv(ctx, sfp[0].o, knh_boxing(ctx, sfp, cid));
+			KNH_SETv(ctx, sfp[0].o, new_Object_boxing(ctx, cid, sfp));
 		}
 	}
 }
