@@ -69,11 +69,11 @@ knh_thread_t knh_thread_self()
 
 /* ------------------------------------------------------------------------ */
 
-int thread_create(knh_thread_t *thread, void *attr, void *(*start_routine)(void *), void * arg)
+int thread_create(knh_thread_t *thread, void *attr, void *(*frun)(void *), void * arg)
 {
 #ifdef KNH_USING_PTHREAD
 #undef KNH_USING_NOTHREAD
-	return pthread_create(thread, attr, start_rutine, arg);
+	return pthread_create(thread, attr, frun, arg);
 #endif
 #ifdef KNH_USING_NOTHREAD
 	return -1;
@@ -120,7 +120,7 @@ int knh_thread_setspecific(knh_thread_key_t key, const void *data)
 void* knh_thread_getspecific(knh_thread_key_t key)
 {
 #ifdef KNH_USING_PTHREAD
-	return pthread_setspecific(key);
+	return pthread_getspecific(key);
 #endif
 #ifdef KNH_USING_NOTHREAD
 	return NULL;
