@@ -121,7 +121,7 @@ int knh_isdir(Ctx *ctx, knh_bytes_t path)
 /* ======================================================================== */
 /* [time] */
 
-knh_uinteger_t knh_initseed()
+knh_uint_t knh_initseed()
 {
 	return time(NULL);
 }
