@@ -35,7 +35,7 @@ extern "C" {
 int
 main(int argc, char **argv)
 {
-	konoha_t konoha = konoha_open(1, 4096);
+	konoha_t konoha = konoha_open(4096);
 	int n = konoha_parseopt(konoha, argc, argv);
 	if(argc - n == 0) {
 		konoha_shell(konoha);
