@@ -45,7 +45,7 @@ static Object *fiboMethod = NULL;
 
 METHOD knh__Script_initfibo(Ctx *ctx, knh_sfp_t *sfp)
 {
-	fiboMethod = knh_Class_getMethod(ctx, CLASS_Script, METHODN_fibo);
+	fiboMethod = (Object*)knh_Class_getMethod(ctx, CLASS_Script, METHODN_fibo);
 	KNH_ASSERT(IS_Method(fiboMethod));
 }
 
