@@ -37,9 +37,6 @@ extern "C" {
 #endif
 
 /* ======================================================================== */
-/* [macros] */
-
-/* ------------------------------------------------------------------------ */
 
 void KNH_ACLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1)
 {
@@ -61,9 +58,9 @@ void KNH_ICLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1)
 /* [SPEC] */
 
 static
-Object *knh_tClass_fdefault__CSPEC(Ctx *ctx, knh_class_t cid)
+Object *knh_ClassTable_fdefault__CSPEC(Ctx *ctx, knh_class_t cid)
 {
-	ClassSpec *cs = (ClassSpec*)ctx->tClass[cid].cspec;
+	ClassSpec *cs = (ClassSpec*)ctx->share->ClassTable[cid].cspec;
 	return UP(DP(cs)->defvalue);
 }
 
@@ -73,46 +70,45 @@ knh_class_t
 KNH_XCLASS(Ctx *ctx, knh_class_t cid, knh_class_t bcid, ClassSpec *cs)
 {
 	if(cid == CLASS_newid) {
-		cid = knh_tClass_newId(ctx);
+		cid = knh_ClassTable_newId(ctx);
 	}else {
-		if(!(cid < ctx->share->tClassSize)) {
-			ctx->share->tClassSize = cid + 1;
-		}
+		KNH_ASSERT(cid + 1 == ctx->share->ClassTableSize);
+		ctx->share->ClassTableSize = cid;
 	}
 
 	char bufcn[CLASSNAME_BUFSIZ];
 	knh_snprintf(bufcn, sizeof(bufcn), KNH_CLASSSPEC_FMT, CLASSN(bcid), knh_String_tochar(DP(cs)->urn));
-	konoha_setClassName(ctx, cid, new_String(ctx, B(bufcn), NULL));
+	konoha_seClassTableName(ctx, cid, new_String(ctx, B(bufcn), NULL));
 	DP(cs)->cid = cid;
 
-	ctx->tClass[cid].bcid   = bcid;
-	ctx->tClass[cid].supcid = bcid;
+	ctx->share->ClassTable[cid].bcid   = bcid;
+	ctx->share->ClassTable[cid].supcid = bcid;
 
 	if(bcid == CLASS_Int) bcid = CLASS_IntX;
 	else if(bcid == CLASS_Float) bcid = CLASS_FloatX;
 	else if(bcid == CLASS_String) bcid = CLASS_StringX;
 
 	DBG2_P("%s\n\tcopying from %s", bufcn, CLASSN(bcid));
-	ctx->tClass[cid].cflag  = ctx->tClass[bcid].cflag;
-	ctx->tClass[cid].oflag  = ctx->tClass[bcid].oflag;
-	ctx->tClass[cid].offset = ctx->tClass[bcid].offset;
+	ctx->share->ClassTable[cid].cflag  = ctx->share->ClassTable[bcid].cflag;
+	ctx->share->ClassTable[cid].oflag  = ctx->share->ClassTable[bcid].oflag;
+	ctx->share->ClassTable[cid].offset = ctx->share->ClassTable[bcid].offset;
 
-	ctx->tClass[cid].sid  = ctx->tClass[bcid].sid;
-	ctx->tClass[cid].size = ctx->tClass[bcid].size;
-	ctx->tClass[cid].bsize  = ctx->tClass[bcid].bsize;
+	ctx->share->ClassTable[cid].sid  = ctx->share->ClassTable[bcid].sid;
+	ctx->share->ClassTable[cid].size = ctx->share->ClassTable[bcid].size;
+	ctx->share->ClassTable[cid].bsize  = ctx->share->ClassTable[bcid].bsize;
 
-	KNH_ASSERT(ctx->tClass[cid].cstruct == NULL);
-	KNH_INITv(ctx->tClass[cid].cstruct, ctx->tClass[bcid].cstruct);
+	KNH_ASSERT(ctx->share->ClassTable[cid].cstruct == NULL);
+	KNH_INITv(ctx->share->ClassTable[cid].cstruct, ctx->share->ClassTable[bcid].cstruct);
 
-	if(ctx->tClass[cid].cmap == NULL) {
-		KNH_INITv(ctx->tClass[cid].cmap, new_ClassMap0(ctx, 4));
+	if(ctx->share->ClassTable[cid].cmap == NULL) {
+		KNH_INITv(ctx->share->ClassTable[cid].cmap, new_ClassMap0(ctx, 4));
 	}
 	else {
-		KNH_ASSERT(IS_ClassMap(ctx->tClass[cid].cmap));
+		KNH_ASSERT(IS_ClassMap(ctx->share->ClassTable[cid].cmap));
 	}
-	KNH_ASSERT(ctx->tClass[cid].cspec == NULL);
-	KNH_INITv(ctx->tClass[cid].cspec, cs);
-	ctx->tClass[cid].fdefault = knh_tClass_fdefault__CSPEC;
+	KNH_ASSERT(ctx->share->ClassTable[cid].cspec == NULL);
+	KNH_INITv(ctx->share->ClassTable[cid].cspec, cs);
+	ctx->share->ClassTable[cid].fdefault = knh_ClassTable_fdefault__CSPEC;
 	return cid;
 }
 
@@ -121,7 +117,7 @@ KNH_XCLASS(Ctx *ctx, knh_class_t cid, knh_class_t bcid, ClassSpec *cs)
 knh_class_t konoha_getcid(Ctx *ctx, char *lname)
 {
 	DBG2_P("lname='%s'", lname);
-	return knh_NameSpace_getClass(ctx, knh_rootNameSpace, B(lname));
+	return knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, B(lname));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -129,13 +125,13 @@ knh_class_t konoha_getcid(Ctx *ctx, char *lname)
 knh_class_t konoha_findcid(Ctx *ctx, knh_bytes_t lname)
 {
 	DBG2_P("lname='%s'", lname.buf);
-	knh_class_t cid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, lname);
+	knh_class_t cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, lname);
 	if(cid != CLASS_unknown) {
 		return cid;
 	}
 	if(knh_bytes_endsWith(lname, STEXT("[]"))) {
 		lname.len -= 2;
-		cid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, lname);
+		cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, lname);
 		if(cid == CLASS_unknown || knh_class_isPrivate(cid)) {
 			return CLASS_Array;
 		}
@@ -143,7 +139,7 @@ knh_class_t konoha_findcid(Ctx *ctx, knh_bytes_t lname)
 	}
 	if(knh_bytes_endsWith(lname, STEXT(".."))) {
 		lname.len -= 2;
-		cid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, lname);
+		cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, lname);
 		if(cid == CLASS_unknown || knh_class_isPrivate(cid)) {
 			return CLASS_Iterator;
 		}
@@ -154,9 +150,9 @@ knh_class_t konoha_findcid(Ctx *ctx, knh_bytes_t lname)
 		if(loc != -1) {
 			knh_bytes_t urn = knh_bytes_last(lname, loc+1); urn.len -= 1;
 			urn = knh_Runtime_aliasURN(ctx, urn);
-			knh_class_t bcid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, knh_bytes_first(lname, loc));
+			knh_class_t bcid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, knh_bytes_first(lname, loc));
 			DBG2_P("cid=%d,%s", bcid, CLASSN(bcid));
-			ClassSpec *cs = (ClassSpec*)konoha_getClassSpec(ctx, bcid, urn);
+			ClassSpec *cs = (ClassSpec*)konoha_geClassTableSpec(ctx, bcid, urn);
 			if(IS_NOTNULL(cs)) {
 				KNH_SETv(ctx, DP(cs)->urn, new_String(ctx, urn, NULL));
 				return KNH_XCLASS(ctx, DP(cs)->cid, bcid, cs);
