@@ -74,7 +74,7 @@ void konoha_setCurrenContext(Ctx *ctx)
 	curctx = ctx;
 #else
 	if(ctx == NULL) {
-		knh_thread_getspecific(ctxkey, NULL);
+		knh_thread_setspecific(ctxkey, NULL);
 	}
 	else {
 		knh_thread_setspecific(ctxkey, ctx);
@@ -108,7 +108,7 @@ KNHAPI(Ctx*) konoha_getThreadContext(Ctx *ctx)
 	knh_thread_t thread = knh_thread_self();
 	if(ctx->threadid != thread) {
 		ctx = (Ctx*)knh_thread_getspecific(ctxkey);
-		if(ctx != NULL && ctx->threadid !== thread) {
+		if(ctx != NULL && ctx->threadid == thread) {
 			return ctx;
 		}
 	}
@@ -333,6 +333,31 @@ void knh_add_history(char *line)
 #endif
 }
 
+/* ------------------------------------------------------------------------ */
+
+int knh_readline_askYesNo(char *prompt, int def)
+{
+	L_TAIL:;
+	char *line = knh_readline(prompt);  /* "Please enter [Y/n] : " */
+	if(line == NULL) return def;
+	int res;
+	if (line[0] == 'y' || line[0] == 'Y') {
+		res = 1;
+	}
+	else if (line[0] == 'n' || line[0] == 'N') {
+		res = 0;
+	}
+	else if (line[0] == '\0') {
+		res = def;
+	}
+	else {
+		fprintf(stdout, "Again. "); fflush(stdout);
+		goto L_TAIL;
+	}
+	free(line);
+	return res;
+}
+
 /* ======================================================================== */
 /* [shell] */
 
@@ -373,6 +398,7 @@ KNHAPI(void) konoha_shell(konoha_t konoha)
 	KONOHA_CHECK_(konoha);
 	Ctx *ctx = konoha.ctx;
 	konoha_setCurrenContext(ctx);
+	knh_Context_setInteractive(ctx, 1);
 	{
 		knh_System__dump(ctx, ctx->sys, KNH_STDOUT, (String*)KNH_NULL);
 		int linenum, linecnt = 0;
@@ -419,6 +445,7 @@ KNHAPI(void) konoha_shell(konoha_t konoha)
 				knh_cwb_clear(cwb);
 				KNH_LOCALBACK(ctx, lsfp);
 				knh_Context_clearstack(ctx);
+				knh_Context_setInteractive(ctx, 0);
 				konoha_setCurrenContext(NULL);
 				return;
 			}
