@@ -358,6 +358,33 @@ knh_Object_t *new_Object_init(Ctx *ctx, knh_flag_t flag, knh_class_t cid, int in
 
 /* ------------------------------------------------------------------------ */
 
+KNHAPI(Object*) new_Object_boxing(Ctx *ctx, knh_class_t cid, knh_sfp_t *sfp)
+{
+	KNH_ASSERT(ctx != NULL);
+	if(unlikely(ctx->unusedObject == NULL)) {
+		KNH_ASSERT(ctx->unusedObjectSize == 0);
+		((knh_Context_t*)ctx)->unusedObject = new_UnusedObject(ctx);
+	}
+	{
+		knh_Object_t *o = ctx->unusedObject;
+		((knh_Context_t*)ctx)->unusedObject = (knh_Object_t*)o->ref;
+		((knh_Context_t*)ctx)->unusedObjectSize -= 1;
+		knh_stat_incUsedObjectSize(ctx, 1);
+		o->h.magic = KNH_OBJECT_MAGIC;
+		knh_Object_RCset(o, KNH_RCGC_INIT);
+		o->h.flag = FLAG_Float;
+		o->h.bcid = ctx->share->ClassTable[cid].bcid;
+		o->h.cid  = cid;
+		o->h.ctxid = ctx->ctxid;
+		o->h.lock  = LOCK_NO;
+		knh_Float_t *v = (knh_Float_t*)o;
+		v->n.data = sfp[0].data;
+		return o;
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+
 void knh_Object_free(Ctx *ctx, knh_Object_t *o)
 {
 	DBG_ASSERT_FREE();
@@ -394,33 +421,6 @@ void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, knh_ftraverse ftr)
 	ctx->share->StructTable[o->h.bcid].ftraverse(ctx, o, ftr);
 }
 
-/* ------------------------------------------------------------------------ */
-
-KNHAPI_(Object*) knh_boxing(Ctx *ctx, knh_sfp_t *sfp, knh_class_t cid)
-{
-	KNH_ASSERT(ctx != NULL);
-	if(unlikely(ctx->unusedObject == NULL)) {
-		KNH_ASSERT(ctx->unusedObjectSize == 0);
-		((knh_Context_t*)ctx)->unusedObject = new_UnusedObject(ctx);
-	}
-	{
-		knh_Object_t *o = ctx->unusedObject;
-		((knh_Context_t*)ctx)->unusedObject = (knh_Object_t*)o->ref;
-		((knh_Context_t*)ctx)->unusedObjectSize -= 1;
-		knh_stat_incUsedObjectSize(ctx, 1);
-		o->h.magic = KNH_OBJECT_MAGIC;
-		knh_Object_RCset(o, KNH_RCGC_INIT);
-		o->h.flag = FLAG_Float;
-		o->h.bcid = ctx->share->ClassTable[cid].bcid;
-		o->h.cid  = cid;
-		o->h.ctxid = ctx->ctxid;
-		o->h.lock  = LOCK_NO;
-		knh_Float_t *v = (knh_Float_t*)o;
-		v->n.data = sfp[0].data;
-		//DBG2_P("cid=%s, ivalue=%lld, fvalue=%f", CLASSN(cid), v->n.ivalue, v->n.fvalue);
-		return o;
-	}
-}
 
 /* ========================================================================= */
 
