@@ -586,12 +586,28 @@ char *knh_format_pscript(Ctx *ctx, char *buf, size_t bufsiz, knh_bytes_t pkgname
 	return NULL;
 }
 
+
+/* ------------------------------------------------------------------------ */
+
+int konohaget(Ctx *ctx, knh_bytes_t pkgname);
+
 /* ------------------------------------------------------------------------ */
 
 NameSpace *knh_System_loadPackage(Ctx *ctx, knh_bytes_t pkgname)
 {
 	char buff[FILENAME_BUFSIZ];
 	char *fpath = knh_format_pscript(ctx, buff, sizeof(buff), pkgname);
+#ifdef KNH_USING_KONOHAGET
+	if(fpath == NULL && knh_Context_isInteractive(ctx)) {
+		fprintf(stdout,
+				"package %s isn't found on your computer.\n"
+				"would you like to fetch from web?\n", (char*)pkgname.buf);
+		if(!knh_readline_askYesNo("Please enter [y/N]: ", 0)) return 0;
+		if(konohaget(ctx, pkgname)) {
+			fpath = knh_format_pscript(ctx, buff, sizeof(buff), pkgname);
+		}
+	}
+#endif
 	if(fpath != NULL) {
 		KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
 		NameSpace *ns = (NameSpace*)knh_DictMap_get__b(ctx,  DP(ctx->sys)->NameSpaceTableDictMap, pkgname);
